@@ -307,19 +307,21 @@ class SSHFileAdaptor(object):
         command = "scp " + SSH_OPTS + " "
         if userkey != None:
             command = command + "-i " + userkey + " "
-        if source_user!=None:
-            command = command + " " + source_user + "@" 
+        
         if source_host != None and source_host!="" and source_host!="localhost":
-            command = command + source_host + ":"
+            if source_user!=None:
+                command = command + " " + source_user + "@" 
+            if source_host!="localhost":
+                command = command + source_host + ":"
         
         # path is a must parameter
         command = command + source_path + " "
         
-        if target_user!=None:
-            command = command + " " + target_user + "@" 
-       
         if target_host != None and target_host!="" and target_host!="localhost":
-            command = command + target_host + ":"
+            if target_user!=None:
+                command = command + " " + target_user + "@" 
+            if target_host!="localhost":
+                command = command + target_host + ":"
             
         command = command + target_path 
         logger.debug(command)    
